AutoRouteDevTools class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

handleNavigate(RootStackRouter router, NavigateRequest request) Future<NavigateResult>
init(RootStackRouter router) → void
Attach this to your router's observers, e.g. via config(): router.config(navigatorObservers: () => [AutoRouteDevTools.navigationObserver()]).
notifyStackChanged() → void
Called by the observer whenever navigation changes.